.. contents::

Changelog
=========

1.0 (2024-05-27)
----------------

- Implement standard listen and connect

- Implement publish and subscribe

- Create **ansar-host** and **ansar-lan** services

- Launch **ansar-wan** cloud service

- Complete **ansar-connect** docs
